@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::OperateObject;
 use AsposeCellsCloud::Object::OperateParameter;
@@ -121,7 +122,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents cells object operate task parameter.',
                                   class => 'CellsObjectOperateTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -131,21 +132,28 @@ __PACKAGE__->method_documentation({
      'operate_object' => {
      	datatype => 'OperateObject',
      	base_name => 'OperateObject',
-     	description => '',
+     	description => 'Represents object operate.',
      	format => '',
      	read_only => '',
      		},
      'operate_parameter' => {
      	datatype => 'OperateParameter',
      	base_name => 'OperateParameter',
-     	description => '',
+     	description => 'Represents operate parameter.',
+     	format => '',
+     	read_only => '',
+     		},
+     'destination_data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'DestinationDataSource',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},
      'destination_workbook' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationWorkbook',
-     	description => '',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},    
@@ -154,12 +162,14 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->swagger_types( {
     'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
+    'destination_data_source' => 'DataSource',
     'destination_workbook' => 'FileSource' 
 } );
 
 __PACKAGE__->attribute_map( {
     'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
+    'destination_data_source' => 'DestinationDataSource',
     'destination_workbook' => 'DestinationWorkbook' 
 } );
 
