@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -129,42 +129,42 @@ __PACKAGE__->method_documentation({
      'max_cfvo' => {
      	datatype => 'ConditionalFormattingValue',
      	base_name => 'MaxCfvo',
-     	description => 'Get or set this ColorScale`s max value object.  Cannot set null or CFValueObject    with type FormatConditionValueType.Min to it.',
+     	description => 'Get or set this ColorScale`s max value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Min to it. ',
      	format => '',
      	read_only => '',
      		},
      'max_color' => {
      	datatype => 'Color',
      	base_name => 'MaxColor',
-     	description => 'Get or set the max value object`s corresponding color.',
+     	description => 'Get or set the gradient color for the maximum value in the range. ',
      	format => '',
      	read_only => '',
      		},
      'mid_cfvo' => {
      	datatype => 'ConditionalFormattingValue',
      	base_name => 'MidCfvo',
-     	description => 'Get or set this ColorScale`s mid value object.  Cannot set CFValueObject   with type FormatConditionValueType.Max or FormatConditionValueType.Min to   it.            ',
+     	description => 'Get or set this ColorScale`s mid value object.            Cannot set CFValueObject with type FormatConditionValueType.Max or FormatConditionValueType.Min to it. ',
      	format => '',
      	read_only => '',
      		},
      'mid_color' => {
      	datatype => 'Color',
      	base_name => 'MidColor',
-     	description => 'Get or set the mid value object`s corresponding color.            ',
+     	description => 'Get or set the gradient color for the middle value in the range. ',
      	format => '',
      	read_only => '',
      		},
      'min_cfvo' => {
      	datatype => 'ConditionalFormattingValue',
      	base_name => 'MinCfvo',
-     	description => 'Get or set this ColorScale`s min value object.  Cannot set null or CFValueObject   with type FormatConditionValueType.Max to it.            ',
+     	description => 'Get or set this ColorScale`s min value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Max to it. ',
      	format => '',
      	read_only => '',
      		},
      'min_color' => {
      	datatype => 'Color',
      	base_name => 'MinColor',
-     	description => 'Get or set the min value object`s corresponding color.',
+     	description => 'Get or set the gradient color for the minimum value in the range. ',
      	format => '',
      	read_only => '',
      		},    
