@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Describes the values of the interpolation points in a gradient scale, dataBar or iconSet.           ',
                                   class => 'ConditionalFormattingValue',
                                   required => [], # TODO
 }                                 );
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'is_gte' => {
      	datatype => 'boolean',
      	base_name => 'IsGTE',
-     	description => 'Get or set the Greater Than Or Equal flag. Use only for icon sets, determines   whether this threshold value uses the greater than or equal to operator.   `false` indicates `greater than` is used instead of `greater than or equal   to`.  Default value is true.            ',
+     	description => 'Get or set the Greater Than Or Equal flag.             Use only for icon sets, determines whether this threshold value uses             the greater than or equal to operator.             `false` indicates `greater than` is used instead of `greater than or equal to`.            Default value is true. ',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => 'Get or set the type of this conditional formatting value object.  Setting     the type to FormatConditionValueType.Min or FormatConditionValueType.Max     will auto set "Value" to null. ',
+     	description => 'Get or set the type of this conditional formatting value object.            Setting the type to FormatConditionValueType.Min or FormatConditionValueType.Max             will auto set "Value" to null. ',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'string',
      	base_name => 'Value',
-     	description => 'Get or set the value of this conditional formatting value object.  It should    be used in conjunction with Type.',
+     	description => 'Get or set the value of this conditional formatting value object.            It should be used in conjunction with Type. ',
      	format => '',
      	read_only => '',
      		},    
