@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -123,7 +123,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a list object on a worksheet.            The ListObject object is a member of the ListObjects collection.             The ListObjects collection contains all the list objects on a worksheet.',
                                   class => 'ListObject',
                                   required => [], # TODO
 }                                 );
@@ -133,147 +133,147 @@ __PACKAGE__->method_documentation({
      'auto_filter' => {
      	datatype => 'AutoFilter',
      	base_name => 'AutoFilter',
-     	description => '',
+     	description => 'Gets auto filter.',
      	format => '',
      	read_only => '',
      		},
      'display_name' => {
      	datatype => 'string',
      	base_name => 'DisplayName',
-     	description => '',
+     	description => 'Gets and sets the display name.',
      	format => '',
      	read_only => '',
      		},
      'start_column' => {
      	datatype => 'int',
      	base_name => 'StartColumn',
-     	description => '',
+     	description => 'Gets the start column of the range.',
      	format => '',
      	read_only => '',
      		},
      'start_row' => {
      	datatype => 'int',
      	base_name => 'StartRow',
-     	description => '',
+     	description => 'Gets the start row of the range.',
      	format => '',
      	read_only => '',
      		},
      'end_column' => {
      	datatype => 'int',
      	base_name => 'EndColumn',
-     	description => '',
+     	description => 'Gets the end column of the range.',
      	format => '',
      	read_only => '',
      		},
      'end_row' => {
      	datatype => 'int',
      	base_name => 'EndRow',
-     	description => '',
+     	description => 'Gets the end  row of the range.',
      	format => '',
      	read_only => '',
      		},
      'list_columns' => {
      	datatype => 'ARRAY[ListColumn]',
      	base_name => 'ListColumns',
-     	description => '',
+     	description => 'Gets ListColumns of the ListObject.',
      	format => '',
      	read_only => '',
      		},
      'show_header_row' => {
      	datatype => 'boolean',
      	base_name => 'ShowHeaderRow',
-     	description => '',
+     	description => 'Gets and sets whether this ListObject show header row.',
      	format => '',
      	read_only => '',
      		},
      'show_table_style_column_stripes' => {
      	datatype => 'boolean',
      	base_name => 'ShowTableStyleColumnStripes',
-     	description => '',
+     	description => 'Indicates whether column stripe formatting is applied.',
      	format => '',
      	read_only => '',
      		},
      'show_table_style_first_column' => {
      	datatype => 'boolean',
      	base_name => 'ShowTableStyleFirstColumn',
-     	description => '',
+     	description => 'Indicates whether the first column in the table should have the style applied.',
      	format => '',
      	read_only => '',
      		},
      'show_table_style_last_column' => {
      	datatype => 'boolean',
      	base_name => 'ShowTableStyleLastColumn',
-     	description => '',
+     	description => 'Indicates whether the last column in the table should have the style applied.',
      	format => '',
      	read_only => '',
      		},
      'show_table_style_row_stripes' => {
      	datatype => 'boolean',
      	base_name => 'ShowTableStyleRowStripes',
-     	description => '',
+     	description => 'Indicates whether row stripe formatting is applied.',
      	format => '',
      	read_only => '',
      		},
      'show_totals' => {
      	datatype => 'boolean',
      	base_name => 'ShowTotals',
-     	description => '',
+     	description => 'Gets and sets whether this ListObject show total row.',
      	format => '',
      	read_only => '',
      		},
      'table_style_name' => {
      	datatype => 'string',
      	base_name => 'TableStyleName',
-     	description => '',
+     	description => 'Gets and sets the table style name.',
      	format => '',
      	read_only => '',
      		},
      'table_style_type' => {
      	datatype => 'string',
      	base_name => 'TableStyleType',
-     	description => '',
+     	description => 'Gets and the built-in table style.',
      	format => '',
      	read_only => '',
      		},
      'data_range' => {
      	datatype => 'Range',
      	base_name => 'DataRange',
-     	description => '',
+     	description => 'Gets the data range of the ListObject.',
      	format => '',
      	read_only => '',
      		},
      'data_source_type' => {
      	datatype => 'string',
      	base_name => 'DataSourceType',
-     	description => '',
+     	description => 'Gets the data source type of the table.',
      	format => '',
      	read_only => '',
      		},
      'comment' => {
      	datatype => 'string',
      	base_name => 'Comment',
-     	description => '',
+     	description => 'Gets and sets the comment of the table.',
      	format => '',
      	read_only => '',
      		},
      'xml_map' => {
      	datatype => 'XmlMap',
      	base_name => 'XmlMap',
-     	description => '',
+     	description => 'Gets an  used for this list.',
      	format => '',
      	read_only => '',
      		},
      'alternative_text' => {
      	datatype => 'string',
      	base_name => 'AlternativeText',
-     	description => '',
+     	description => 'Gets and sets the alternative text.',
      	format => '',
      	read_only => '',
      		},
      'alternative_description' => {
      	datatype => 'string',
      	base_name => 'AlternativeDescription',
-     	description => '',
+     	description => 'Gets and sets the alternative description.',
      	format => '',
      	read_only => '',
      		},
