@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           This class specifies the shadow effect of the chart element or shape.           ',
                                   class => 'ShadowEffect',
                                   required => [], # TODO
 }                                 );
