@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,9 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# DeleteDocumentUnProtectFromChangesRequest.name : The workbook name.  ,
-# DeleteDocumentUnProtectFromChangesRequest.folder : Original workbook folder.  ,
-# DeleteDocumentUnProtectFromChangesRequest.storageName : Storage name.   
+# DeleteDocumentUnProtectFromChangesRequest.name : The file name.  ,
+# DeleteDocumentUnProtectFromChangesRequest.folder : The folder where the file is situated.  ,
+# DeleteDocumentUnProtectFromChangesRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -72,7 +72,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_document_un_protect_from_changes' } = { 
-    	summary => 'Unprotects document from changes.',
+    	summary => 'Excel file cancel write protection.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -123,21 +123,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
