@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -60,9 +60,10 @@ sub new {
 
 # Run Operation Request
 # DeleteMetadataRequest.File : File to upload  ,
-# DeleteMetadataRequest.type :   ,
-# DeleteMetadataRequest.password :   ,
-# DeleteMetadataRequest.checkExcelRestriction :    
+# DeleteMetadataRequest.type : Cells document property name.  ,
+# DeleteMetadataRequest.outFormat : The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)  ,
+# DeleteMetadataRequest.password : The password needed to open an Excel file.  ,
+# DeleteMetadataRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.   
 
 {
     my $params = {
@@ -73,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_metadata' } = { 
-    	summary => '',
+    	summary => 'Delete cells document properties in Excel file, and save them is various formats.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -103,6 +104,10 @@ sub run_http_request {
         $query_params->{'type'} = $client->to_query_value($self->type);      
     }
 
+    if(defined $self->out_format){
+        $query_params->{'outFormat'} = $client->to_query_value($self->out_format);      
+    }
+
     if(defined $self->password){
         $query_params->{'password'} = $client->to_query_value($self->password);      
     }
@@ -140,21 +145,28 @@ __PACKAGE__->method_documentation({
      'type' => {
      	datatype => 'string',
      	base_name => 'type',
-     	description => '',
+     	description => 'Cells document property name.',
+     	format => '',
+     	read_only => '',
+     		},
+     'out_format' => {
+     	datatype => 'string',
+     	base_name => 'outFormat',
+     	description => 'The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => '',
+     	description => 'Whether check restriction of excel file when user modify cells related objects.',
      	format => '',
      	read_only => '',
      		},    
@@ -164,6 +176,7 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->attribute_map( {
     'file' => 'File',
     'type' => 'type',
+    'out_format' => 'outFormat',
     'password' => 'password',
     'check_excel_restriction' => 'checkExcelRestriction' 
 } );
