@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -61,8 +61,8 @@ sub new {
 # Run Operation Request
 # DeleteWorksheetValidationsRequest.name : The workbook name.  ,
 # DeleteWorksheetValidationsRequest.sheetName : The worksheet name.  ,
-# DeleteWorksheetValidationsRequest.folder : Original workbook folder.  ,
-# DeleteWorksheetValidationsRequest.storageName : Storage name.   
+# DeleteWorksheetValidationsRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetValidationsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_validations' } = { 
-    	summary => 'Delete all validations in worksheet.',
+    	summary => 'Delete all validations in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,14 +144,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
