@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetPivotTableFilterRequest.name : The workbook name.  ,
+# GetWorksheetPivotTableFilterRequest.name : The file name.  ,
 # GetWorksheetPivotTableFilterRequest.sheetName : The worksheet name.  ,
-# GetWorksheetPivotTableFilterRequest.pivotTableIndex : Gets the PivotTable report by index.  ,
-# GetWorksheetPivotTableFilterRequest.filterIndex : Gets the pivotfilter object at the specific index.  ,
-# GetWorksheetPivotTableFilterRequest.folder : Original workbook folder.  ,
-# GetWorksheetPivotTableFilterRequest.storageName : Storage name.   
+# GetWorksheetPivotTableFilterRequest.pivotTableIndex : The PivotTable index in the worksheet.  ,
+# GetWorksheetPivotTableFilterRequest.filterIndex : The pivot filter index of PivotTable.  ,
+# GetWorksheetPivotTableFilterRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetPivotTableFilterRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_pivot_table_filter' } = { 
-    	summary => 'Gets pivot table filters in worksheet.',
+    	summary => 'Retrieve PivotTable filters in the worksheet.',
         params => $params,
         returns => 'PivotFilterResponse',
     };
@@ -144,7 +144,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -158,28 +158,28 @@ __PACKAGE__->method_documentation({
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => 'Gets the PivotTable report by index.',
+     	description => 'The PivotTable index in the worksheet.',
      	format => '',
      	read_only => '',
      		},
      'filter_index' => {
      	datatype => 'int',
      	base_name => 'filterIndex',
-     	description => 'Gets the pivotfilter object at the specific index.',
+     	description => 'The pivot filter index of PivotTable.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
