@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,14 +59,14 @@ sub new {
 
 
 # Run Operation Request
-# PostCopyWorksheetRowsRequest.name : The workbook name.  ,
+# PostCopyWorksheetRowsRequest.name : The file name.  ,
 # PostCopyWorksheetRowsRequest.sheetName : The worksheet name.  ,
 # PostCopyWorksheetRowsRequest.sourceRowIndex : Source row index  ,
 # PostCopyWorksheetRowsRequest.destinationRowIndex : Destination row index  ,
 # PostCopyWorksheetRowsRequest.rowNumber : The copied row number  ,
 # PostCopyWorksheetRowsRequest.worksheet : The worksheet name.  ,
-# PostCopyWorksheetRowsRequest.folder : Original workbook folder.  ,
-# PostCopyWorksheetRowsRequest.storageName : Storage name.   
+# PostCopyWorksheetRowsRequest.folder : The folder where the file is situated.  ,
+# PostCopyWorksheetRowsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -77,7 +77,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_copy_worksheet_rows' } = { 
-    	summary => 'Copies data and formats of some whole rows in worksheet.',
+    	summary => 'Copy data and formats from specific entire rows in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -150,7 +150,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -192,14 +192,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
