@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostHideWorksheetColumnsRequest.name : The workbook name.  ,
+# PostHideWorksheetColumnsRequest.name : The file name.  ,
 # PostHideWorksheetColumnsRequest.sheetName : The worksheet name.  ,
 # PostHideWorksheetColumnsRequest.startColumn : The begin column index to be operated.  ,
 # PostHideWorksheetColumnsRequest.totalColumns : Number of columns to be operated.  ,
-# PostHideWorksheetColumnsRequest.folder : Original workbook folder.  ,
-# PostHideWorksheetColumnsRequest.storageName : Storage name.   
+# PostHideWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# PostHideWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_hide_worksheet_columns' } = { 
-    	summary => 'Hide worksheet columns.',
+    	summary => 'Hide worksheet columns in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -140,7 +140,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -168,14 +168,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
