@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# PostProtectWorkbookRequest.name : The workbook name.  ,
-# PostProtectWorkbookRequest.protection : The protection settings.  ,
-# PostProtectWorkbookRequest.folder : Original workbook folder.  ,
-# PostProtectWorkbookRequest.storageName : Storage name.   
+# PostProtectWorkbookRequest.name : The file name.  ,
+# PostProtectWorkbookRequest.protectWorkbookRequest : The protection settings.  ,
+# PostProtectWorkbookRequest.folder : The folder where the file is situated.  ,
+# PostProtectWorkbookRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_protect_workbook' } = { 
-    	summary => 'Protects workbook.',
+    	summary => 'Excel protection.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -113,9 +113,9 @@ sub run_http_request {
     my $_body_data;
 
     # body params
-    if (defined $self->protection) {
-        #$_body_data = $self->protection;
-         $_body_data = JSON->new->convert_blessed->encode( $self->protection);
+    if (defined $self->protect_workbook_request) {
+        #$_body_data = $self->protect_workbook_request;
+         $_body_data = JSON->new->convert_blessed->encode( $self->protect_workbook_request);
     }
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -130,13 +130,13 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
-     'protection' => {
-     	datatype => 'WorkbookProtectionRequest',
-     	base_name => 'protection',
+     'protect_workbook_request' => {
+     	datatype => 'ProtectWorkbookRequest',
+     	base_name => 'protectWorkbookRequest',
      	description => 'The protection settings.',
      	format => '',
      	read_only => '',
@@ -144,14 +144,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
@@ -160,7 +160,7 @@ __PACKAGE__->method_documentation({
 
 __PACKAGE__->attribute_map( {
     'name' => 'name',
-    'protection' => 'protection',
+    'protect_workbook_request' => 'protectWorkbookRequest',
     'folder' => 'folder',
     'storage_name' => 'storageName' 
 } );
