@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostUngroupWorksheetColumnsRequest.name :   ,
-# PostUngroupWorksheetColumnsRequest.sheetName :   ,
-# PostUngroupWorksheetColumnsRequest.firstIndex :   ,
-# PostUngroupWorksheetColumnsRequest.lastIndex :   ,
-# PostUngroupWorksheetColumnsRequest.folder :   ,
-# PostUngroupWorksheetColumnsRequest.storageName :    
+# PostUngroupWorksheetColumnsRequest.name : The file name.  ,
+# PostUngroupWorksheetColumnsRequest.sheetName : The worksheet name.  ,
+# PostUngroupWorksheetColumnsRequest.firstIndex : The first column index to be operated.  ,
+# PostUngroupWorksheetColumnsRequest.lastIndex : The last column index to be operated.  ,
+# PostUngroupWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# PostUngroupWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_ungroup_worksheet_columns' } = { 
-    	summary => '',
+    	summary => 'Ungroup worksheet columns.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -140,42 +140,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'first_index' => {
      	datatype => 'int',
      	base_name => 'firstIndex',
-     	description => '',
+     	description => 'The first column index to be operated.',
      	format => '',
      	read_only => '',
      		},
      'last_index' => {
      	datatype => 'int',
      	base_name => 'lastIndex',
-     	description => '',
+     	description => 'The last column index to be operated.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
