@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# PostUnhideWorksheetColumnsRequest.name : The workbook name.  ,
+# PostUnhideWorksheetColumnsRequest.name : The file name.  ,
 # PostUnhideWorksheetColumnsRequest.sheetName : The worksheet name.  ,
 # PostUnhideWorksheetColumnsRequest.startColumn : The begin column index to be operated.  ,
 # PostUnhideWorksheetColumnsRequest.totalColumns : Number of columns to be operated.  ,
 # PostUnhideWorksheetColumnsRequest.width : Gets and sets the column width in unit of characters.  ,
-# PostUnhideWorksheetColumnsRequest.folder : Original workbook folder.  ,
-# PostUnhideWorksheetColumnsRequest.storageName : Storage name.   
+# PostUnhideWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# PostUnhideWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_unhide_worksheet_columns' } = { 
-    	summary => 'Unhide worksheet columns.',
+    	summary => 'Unhide worksheet columns in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -145,7 +145,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -180,14 +180,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
