@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,14 +59,14 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCellSetValueRequest.name :   ,
-# PostWorksheetCellSetValueRequest.sheetName :   ,
-# PostWorksheetCellSetValueRequest.cellName :   ,
-# PostWorksheetCellSetValueRequest.value :   ,
-# PostWorksheetCellSetValueRequest.type :   ,
-# PostWorksheetCellSetValueRequest.formula :   ,
-# PostWorksheetCellSetValueRequest.folder :   ,
-# PostWorksheetCellSetValueRequest.storageName :    
+# PostWorksheetCellSetValueRequest.name : The file name.  ,
+# PostWorksheetCellSetValueRequest.sheetName : The worksheet name.  ,
+# PostWorksheetCellSetValueRequest.cellName : The cell name.  ,
+# PostWorksheetCellSetValueRequest.value : The cell value.  ,
+# PostWorksheetCellSetValueRequest.type : The value type.  ,
+# PostWorksheetCellSetValueRequest.formula : Formula for cell  ,
+# PostWorksheetCellSetValueRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetCellSetValueRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -77,7 +77,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_cell_set_value' } = { 
-    	summary => '',
+    	summary => 'Set cell value using cell name in the worksheet.',
         params => $params,
         returns => 'CellResponse',
     };
@@ -152,56 +152,56 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'cell_name' => {
      	datatype => 'string',
      	base_name => 'cellName',
-     	description => '',
+     	description => 'The cell name.',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'string',
      	base_name => 'value',
-     	description => '',
+     	description => 'The cell value.',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'type',
-     	description => '',
+     	description => 'The value type.',
      	format => '',
      	read_only => '',
      		},
      'formula' => {
      	datatype => 'string',
      	base_name => 'formula',
-     	description => '',
+     	description => 'Formula for cell',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
