@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,14 +59,14 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetPivotTableMoveRequest.name : The workbook name.  ,
+# PostWorksheetPivotTableMoveRequest.name : The file name.  ,
 # PostWorksheetPivotTableMoveRequest.sheetName : The worksheet name.  ,
 # PostWorksheetPivotTableMoveRequest.pivotTableIndex : Gets the PivotTable report by index.  ,
 # PostWorksheetPivotTableMoveRequest.row : Row index.  ,
 # PostWorksheetPivotTableMoveRequest.column : Column index.  ,
 # PostWorksheetPivotTableMoveRequest.destCellName : The dest cell name.  ,
-# PostWorksheetPivotTableMoveRequest.folder : Original workbook folder.  ,
-# PostWorksheetPivotTableMoveRequest.storageName : Storage name.   
+# PostWorksheetPivotTableMoveRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetPivotTableMoveRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -77,7 +77,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_pivot_table_move' } = { 
-    	summary => 'Moves pivot table in worksheet.',
+    	summary => 'Move PivotTable in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -152,7 +152,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -194,14 +194,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
