@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetSparklineGroupRequest.name :   ,
-# PostWorksheetSparklineGroupRequest.sheetName :   ,
-# PostWorksheetSparklineGroupRequest.sparklineGroupIndex :   ,
-# PostWorksheetSparklineGroupRequest.sparklineGroup :   ,
-# PostWorksheetSparklineGroupRequest.folder :   ,
-# PostWorksheetSparklineGroupRequest.storageName :    
+# PostWorksheetSparklineGroupRequest.name : The file name.  ,
+# PostWorksheetSparklineGroupRequest.sheetName : The worksheet name.  ,
+# PostWorksheetSparklineGroupRequest.sparklineGroupIndex : The zero based index of the element.  ,
+# PostWorksheetSparklineGroupRequest.sparklineGroup : Spark line group description.  ,
+# PostWorksheetSparklineGroupRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetSparklineGroupRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_sparkline_group' } = { 
-    	summary => '',
+    	summary => 'Update a sparkline group in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,42 +144,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'sparkline_group_index' => {
      	datatype => 'int',
      	base_name => 'sparklineGroupIndex',
-     	description => '',
+     	description => 'The zero based index of the element.',
      	format => '',
      	read_only => '',
      		},
      'sparkline_group' => {
      	datatype => 'SparklineGroup',
      	base_name => 'sparklineGroup',
-     	description => '',
+     	description => 'Spark line group description.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
