@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PutAddNewWorksheetRequest.name :   ,
-# PutAddNewWorksheetRequest.sheetName :   ,
-# PutAddNewWorksheetRequest.position :   ,
-# PutAddNewWorksheetRequest.sheettype :   ,
-# PutAddNewWorksheetRequest.folder :   ,
-# PutAddNewWorksheetRequest.storageName :    
+# PutAddNewWorksheetRequest.name : The file name.  ,
+# PutAddNewWorksheetRequest.sheetName : The new sheet name.  ,
+# PutAddNewWorksheetRequest.position : The new sheet position.  ,
+# PutAddNewWorksheetRequest.sheettype : Specifies the worksheet type(VB/Worksheet/Chart/BIFF4Macro/InternationalMacro/Other/Dialog).  ,
+# PutAddNewWorksheetRequest.folder : The folder where the file is situated.  ,
+# PutAddNewWorksheetRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_add_new_worksheet' } = { 
-    	summary => '',
+    	summary => 'Add a new worksheet in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -140,42 +140,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The new sheet name.',
      	format => '',
      	read_only => '',
      		},
      'position' => {
      	datatype => 'int',
      	base_name => 'position',
-     	description => '',
+     	description => 'The new sheet position.',
      	format => '',
      	read_only => '',
      		},
      'sheettype' => {
      	datatype => 'string',
      	base_name => 'sheettype',
-     	description => '',
+     	description => 'Specifies the worksheet type(VB/Worksheet/Chart/BIFF4Macro/InternationalMacro/Other/Dialog).',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
