@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PutWorksheetBackgroundRequest.name : The workbook name.  ,
+# PutWorksheetBackgroundRequest.name : The file name.  ,
 # PutWorksheetBackgroundRequest.sheetName : The worksheet name.  ,
 # PutWorksheetBackgroundRequest.picPath : picture full filename.  ,
-# PutWorksheetBackgroundRequest.folder : Original workbook folder.  ,
-# PutWorksheetBackgroundRequest.storageName : Storage name.  ,
+# PutWorksheetBackgroundRequest.imageAdaptOption :   ,
+# PutWorksheetBackgroundRequest.folder : The folder where the file is situated.  ,
+# PutWorksheetBackgroundRequest.storageName : The storage name where the file is situated.  ,
 # PutWorksheetBackgroundRequest.File : File to upload   
 
 {
@@ -75,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_worksheet_background' } = { 
-    	summary => 'Sets background image in worksheet.',
+    	summary => 'Set background image in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -115,6 +116,10 @@ sub run_http_request {
         $query_params->{'picPath'} = $client->to_query_value($self->pic_path);      
     }
 
+    if(defined $self->image_adapt_option){
+        $query_params->{'imageAdaptOption'} = $client->to_query_value($self->image_adapt_option);      
+    }
+
     if(defined $self->folder){
         $query_params->{'folder'} = $client->to_query_value($self->folder);      
     }
@@ -145,7 +150,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -163,17 +168,24 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'image_adapt_option' => {
+     	datatype => 'string',
+     	base_name => 'imageAdaptOption',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},
@@ -191,6 +203,7 @@ __PACKAGE__->attribute_map( {
     'name' => 'name',
     'sheet_name' => 'sheetName',
     'pic_path' => 'picPath',
+    'image_adapt_option' => 'imageAdaptOption',
     'folder' => 'folder',
     'storage_name' => 'storageName',
     'file' => 'File' 
