@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,17 +59,17 @@ sub new {
 
 
 # Run Operation Request
-# PutWorksheetListObjectRequest.name :   ,
-# PutWorksheetListObjectRequest.sheetName :   ,
-# PutWorksheetListObjectRequest.startRow :   ,
-# PutWorksheetListObjectRequest.startColumn :   ,
-# PutWorksheetListObjectRequest.endRow :   ,
-# PutWorksheetListObjectRequest.endColumn :   ,
-# PutWorksheetListObjectRequest.folder :   ,
-# PutWorksheetListObjectRequest.hasHeaders :   ,
-# PutWorksheetListObjectRequest.displayName :   ,
-# PutWorksheetListObjectRequest.showTotals :   ,
-# PutWorksheetListObjectRequest.storageName :    
+# PutWorksheetListObjectRequest.name : The file name.  ,
+# PutWorksheetListObjectRequest.sheetName : The worksheet name.  ,
+# PutWorksheetListObjectRequest.startRow : The start row of the list range.  ,
+# PutWorksheetListObjectRequest.startColumn : The start column of the list range.  ,
+# PutWorksheetListObjectRequest.endRow : The start row of the list range.  ,
+# PutWorksheetListObjectRequest.endColumn : The start column of the list range.  ,
+# PutWorksheetListObjectRequest.folder : The folder where the file is situated.  ,
+# PutWorksheetListObjectRequest.hasHeaders : Indicate whether the range has headers.  ,
+# PutWorksheetListObjectRequest.displayName : Indicate whether display name.  ,
+# PutWorksheetListObjectRequest.showTotals : Indicate whether show totals.  ,
+# PutWorksheetListObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -80,7 +80,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_worksheet_list_object' } = { 
-    	summary => '',
+    	summary => 'Add a ListObject in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -165,77 +165,77 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'start_row' => {
      	datatype => 'int',
      	base_name => 'startRow',
-     	description => '',
+     	description => 'The start row of the list range.',
      	format => '',
      	read_only => '',
      		},
      'start_column' => {
      	datatype => 'int',
      	base_name => 'startColumn',
-     	description => '',
+     	description => 'The start column of the list range.',
      	format => '',
      	read_only => '',
      		},
      'end_row' => {
      	datatype => 'int',
      	base_name => 'endRow',
-     	description => '',
+     	description => 'The start row of the list range.',
      	format => '',
      	read_only => '',
      		},
      'end_column' => {
      	datatype => 'int',
      	base_name => 'endColumn',
-     	description => '',
+     	description => 'The start column of the list range.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'has_headers' => {
      	datatype => 'string',
      	base_name => 'hasHeaders',
-     	description => '',
+     	description => 'Indicate whether the range has headers.',
      	format => '',
      	read_only => '',
      		},
      'display_name' => {
      	datatype => 'string',
      	base_name => 'displayName',
-     	description => '',
+     	description => 'Indicate whether display name.',
      	format => '',
      	read_only => '',
      		},
      'show_totals' => {
      	datatype => 'string',
      	base_name => 'showTotals',
-     	description => '',
+     	description => 'Indicate whether show totals.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
